sydney_hobart_times: Sydney to Hobart winning times

sydney_hobart_timesR Documentation

Sydney to Hobart winning times

Description

Winning times for the Sydney to Hobart Yacht Race. An annual sail yacht race over 1170km, from Sydney's harbour, to Hobart in Tasmania. The race is infamous for the rough conditions, long distance, and large number of dropouts in some years. The data include the winning time, and the number of starting yachts, and the number of yachts reaching the finish.

Usage

data(sydney_hobart_times)

Format

A data frame with 72 rows and 5 variables:

Year

integer Year race was held

Time

double Total time (days)

fleet_start

integer Number yachts at start

fleet_finish

integer Number yachts at finish

Time_record

double Record race up to this year

<https://en.wikipedia.org/wiki/Sydney_to_Hobart_Yacht_Race>

Examples

data(sydney_hobart_times)
with(sydney_hobart_times, {
    plot(Year, Time)
    lines(Year, Time_record, type='s', col="red")
})


lgrdata documentation built on Oct. 2, 2026, 1:08 a.m.